@@ -112,7 +112,7 @@ static char *errlist[] = {
   "Input line too long"
 };
 
-static void NO_RETURN error P((enum error_code));
+static void error P((enum error_code));
 static int parse_data P((char *, unsigned long *));
 static void parse_location P((char *, struct sgmls *));
 static void parse_notation P((char *, notation_s *));
@@ -1017,7 +1017,7 @@ UNIV xrealloc(p, n)
   return p;
 }
 
-static NO_RETURN
+static
 void error(num)
      enum error_code num;
 {
